@@ -11,6 +11,7 @@ LIDO_ADDRESSES = {
     Network.Ropsten: "0xd40EefCFaB888C9159a61221def03bF77773FC19",
     Network.Rinkeby: "0xF4242f9d78DB7218Ad72Ee3aE14469DBDE8731eD",
     Network.Kintsugi: "0x3a6a994AC0CC96b6DDbaA99F10769384Fa14227B",
+    Network.Kiln: "0x3E50180cf438e185ec52Ade55855718584541476",
 }
 
 NODE_OPS_ADDRESSES = {
@@ -19,6 +20,7 @@ NODE_OPS_ADDRESSES = {
     Network.Ropsten: "0x32c6f34F3920E8c0074241619c02be2fB722a68d",
     Network.Rinkeby: "0x776dFe7Ec5D74526Aa65898B7d77FCfdf15ffBe6",
     Network.Kintsugi: "0xeb7D01f713F59EFfB350D05b7AF66720373D4F41",
+    Network.Kiln: "0xb849C5b35DC45277Bad5c6F2c6C77183d842367c",
 }
 
 
